==> spincast-plugins-routing-0.9.50-sources.jar: org/spincast/plugins/routing/RouteFactory.java <==
package org.spincast.plugins.routing;

import java.util.List;
import java.util.Set;

import org.spincast.core.exchange.RequestContext;
import org.spincast.core.routing.Handler;
import org.spincast.core.routing.HttpMethod;
import org.spincast.core.routing.Route;
import org.spincast.core.routing.RoutingType;

import com.google.inject.assistedinject.Assisted;

public interface RouteFactory<R extends RequestContext<?>> {

    public Route<R> createRoute(@Assisted("id") String id,
                                @Assisted("isResourceRoute") boolean isResourceRoute,
                                @Assisted("isSpicastCoreRouteOrPluginRoute") boolean isSpicastCoreRouteOrPluginRoute,
                                @Assisted("httpMethods") Set<HttpMethod> httpMethods,
                                @Assisted("path") String path,
                                @Assisted("routingTypes") Set<RoutingType> routingTypes,
                                @Assisted("before") List<Handler<R>> beforeFilters,
                                @Assisted("main") Handler<R> mainHandler,
                                @Assisted("after") List<Handler<R>> afterFilters,
                                @Assisted("position") int position,
                                @Assisted("acceptedContentTypes") Set<String> acceptedContentTypes,
                                @Assisted("filterIdsToSkip") Set<String> filterIdsToSkip,
                                @Assisted("skipResources") boolean skipResources);
}

==> spincast-plugins-routing-0.9.55-sources.jar: org/spincast/plugins/routing/RouteFactory.java <==
package org.spincast.plugins.routing;

import java.util.List;
import java.util.Set;

import javax.annotation.Nullable;

import org.spincast.core.exchange.RequestContext;
import org.spincast.core.routing.Handler;
import org.spincast.core.routing.HttpMethod;
import org.spincast.core.routing.Route;
import org.spincast.core.routing.RoutingType;
import org.spincast.core.routing.StaticResource;

import com.google.inject.assistedinject.Assisted;

public interface RouteFactory<R extends RequestContext<?>> {

    public Route<R> createRoute(@Assisted("id") String id,
                                @Assisted("isResourceRoute") boolean isResourceRoute,
                                @Assisted("staticResource") @Nullable StaticResource<R> staticResource,
                                @Assisted("isSpicastCoreRouteOrPluginRoute") boolean isSpicastCoreRouteOrPluginRoute,
                                @Assisted("httpMethods") Set<HttpMethod> httpMethods,
                                @Assisted("path") String path,
                                @Assisted("routingTypes") Set<RoutingType> routingTypes,
                                @Assisted("before") List<Handler<R>> beforeFilters,
                                @Assisted("main") Handler<R> mainHandler,
                                @Assisted("after") List<Handler<R>> afterFilters,
                                @Assisted("position") int position,
                                @Assisted("acceptedContentTypes") Set<String> acceptedContentTypes,
                                @Assisted("filterIdsToSkip") Set<String> filterIdsToSkip,
                                @Assisted("skipResources") boolean skipResources);
}
